@@ -99,6 +99,7 @@ get.Qmat = function(p){
 #'
 #' @return list with the following fields for each simulation chain:
 #' \itemize{
+#'   \item \strong{YStar}: \code{nS x nY}, change variable
 #'   \item \strong{phiStar}: \code{nS x nF}, climate change responses
 #'   \item \strong{etaStar}: \code{nS x nY}, deviation from the climate change response
 #'   due to the internal variability, for \code{Xmat}
@@ -466,14 +467,6 @@ QUALYPSO.check.option = function(listOption){
   # nMCMC
   listOption$nMCMC = listOption$nKeep+listOption$nBurn
 
-  # nCluster
-  if('nCluster' %in% names(listOption)){
-    nCluster = listOption[['nCluster']]
-    if(!(is.numeric(nCluster)&(nCluster>=0))) stop('wrong value for nCluster')
-  }else{
-    listOption[['nCluster']] = 1
-  }
-
   # probCI
   if('probCI' %in% names(listOption)){
     probCI = listOption[['probCI']]
@@ -593,18 +586,9 @@ QUALYPSO.ANOVA = function(phiStar,scenAvail,listOption=NULL,namesEff){
 
   #########  Apply ANOVA for each time step: parallel computation over time steps #########
   # apply parallel computation only if more than one cluster has been indicated
-  if(listOption$nCluster==1){
-    Anova.POST = list()
-    for(i in 1:n){
-      Anova.POST[[i]] = QUALYPSO.ANOVA.i(phiStar.i=phiStar[,i], nMCMC=listOption$nMCMC,listScenarioInput = listScenarioInput)
-    }
-  }else{
-    i = NULL # avoid warning during check
-    Anova.POST <- foreach(i=1:n, .multicombine=TRUE,
-                          .export=c("QUALYPSO.ANOVA.i")) %dopar% {
-                            POST.out = QUALYPSO.ANOVA.i(phiStar.i=phiStar[,i], nMCMC=listOption$nMCMC,listScenarioInput = listScenarioInput)
-                            return(POST.out)
-                          }
+  Anova.POST = list()
+  for(i in 1:n){
+    Anova.POST[[i]] = QUALYPSO.ANOVA.i(phiStar.i=phiStar[,i], nMCMC=listOption$nMCMC,listScenarioInput = listScenarioInput)
   }
 
 
@@ -991,16 +975,13 @@ lm.ANOVA = function(phiStar,scenAvail,listOption=NULL,namesEff){
 #'   \item \strong{nKeep}: if \code{ANOVAmethod=="QUALYPSO"}, number of kept samples (default: 2000).
 #'   If \code{nKeep} is too small, MCMC samples might not represent correctly the posterior
 #'   distributions of inferred parameters.
-#'   \item \strong{nCluster}: number of clusters used for the parallelization (default: 1).
-#'   When \code{nCluster} is greater than one, parallelization is used to
-#'   apply \code{QUALYPSO} over multiple time steps or grid points simultaneously.
 #'   \item \strong{probCI}: probability (in [0,1]) for the confidence intervals, \code{probCI = 0.9} by default.
 #'   \item \strong{quantilePosterior}: vector of probabilities (in [0,1]) for which
 #'   we compute the quantiles from the posterior distributions
 #'    \code{quantilePosterior = c(0.005,0.025,0.05,0.1,0.25,0.33,0.5,0.66,0.75,0.9,0.95,0.975,0.995)} by default.
 #'   \item \strong{climResponse}: NULL by default. If it is provided, it must correspond to the outputs
-#'   of \code{\link{fit.climate.response}}, i.e. a list with \code{phiStar} [nS x nF], \code{etaStar} [nS x nY],
-#'    \code{phi} [nS x nF] and \code{varInterVariability} [scalar] if \code{Y} is a matrix [nS x nY],
+#'   of \code{\link{fit.climate.response}}, i.e. a list with \code{YStar} [nS x nY], \code{phiStar} [nS x nF],
+#'   \code{etaStar} [nS x nY], \code{phi} [nS x nF] and \code{varInterVariability} [scalar] if \code{Y} is a matrix [nS x nY],
 #'    or a list with \code{phiStar} [nG x nS x nF], \code{etaStar} [nG x nS x nY], \code{phi} [nG x nS x nF] and
 #'     \code{varInterVariability} vector of length \code{nG} if \code{Y} is an array [nG x nS x nY].
 #' }
@@ -1008,7 +989,7 @@ lm.ANOVA = function(phiStar,scenAvail,listOption=NULL,namesEff){
 #' @return  List providing the results for each of the \code{n} values of \code{Xfut}
 #' if \code{Y} is a matrix or for each grid point if \code{Y} is an array, with the following fields:
 #' \itemize{
-#'   \item \strong{CLIMATEESPONSE}: list of climate change responses and
+#'   \item \strong{CLIMATERESPONSE}: list of climate change responses and
 #'  corresponding internal variability. Contains \code{phiStar} (climate change
 #'  responses), \code{etaStar} (deviation from the climate change responses as
 #'  a result of internal variability), \code{Ystar} (change variable from the
@@ -1311,12 +1292,6 @@ QUALYPSO = function(Y,scenAvail,X=NULL,Xfut=NULL,iFut=NULL,listOption=NULL){
     }
   }
 
-  # register clusters
-  if(listOption$nCluster>1){
-    cl <- parallel::makeCluster(listOption$nCluster)
-    doParallel::registerDoParallel(cl)
-  }
-
 
   ##############################################
   # check presence of NAs in climate projections
@@ -1362,7 +1337,6 @@ QUALYPSO = function(Y,scenAvail,X=NULL,Xfut=NULL,iFut=NULL,listOption=NULL){
       varInterVariability = vector(length=nG)
 
       # parallelize if required
-      if(listOption$nCluster==1){
         for(g in 1:nG){
           # check is some simulation chains are entirely missing
           hasAllNa = apply(Y[g,,],1,function(x) all(is.na(x)))
@@ -1385,31 +1359,6 @@ QUALYPSO = function(Y,scenAvail,X=NULL,Xfut=NULL,iFut=NULL,listOption=NULL){
             varInterVariability[g] = climResponse$varInterVariability
           }
         }
-      }else{
-        g = NULL # avoid warning during check
-        climResponse <- foreach(g=1:nG,.export=c("fit.climate.response")) %dopar% {
-          # check is some simulation chains are entirely missing
-          hasAllNa = apply(Y[g,,],1,function(x) all(is.na(x)))
-          if(any(hasAllNa)){
-            climResponse.g = list(phiStar = NA, etaStar = NA, phi = NA,
-                                  varInterVariability = NA)
-          }else{
-            climResponse.g = fit.climate.response(Y[g,,],
-                                                  args.smooth.spline=listOption$args.smooth.spline,
-                                                  Xmat=Xmat, Xfut=Xfut,
-                                                  typeChangeVariable=listOption$typeChangeVariable)
-          }
-          return(climResponse.g)
-        }
-
-        # fill the matrices
-        for(g in 1:nG){
-          phiStar[g,,] = climResponse[[g]]$phiStar
-          etaStar[g,,] = climResponse[[g]]$etaStar
-          phi[g,,] = climResponse[[g]]$phi
-          varInterVariability[g] = climResponse[[g]]$varInterVariability
-        }
-      }
     }else{
       climResponse = listOption$climResponse
       YStar = climResponse$YStar
@@ -1496,15 +1445,10 @@ QUALYPSO = function(Y,scenAvail,X=NULL,Xfut=NULL,iFut=NULL,listOption=NULL){
   DECOMPVAR = Vbind/replicate(n = ncol(Vbind), TOTALVAR)
   colnames(DECOMPVAR) = c(namesEff,"ResidualVar","InternalVar")
 
-  # stop clusters
-  if(listOption$nCluster>1){
-    parallel::stopCluster(cl)
-  }
-
 
   #############################################
   # return results
-  return(list(CLIMATEESPONSE=list(phiStar=phiStar,etaStar=etaStar,YStar=YStar,phi=phi),
+  return(list(CLIMATERESPONSE=list(phiStar=phiStar,etaStar=etaStar,YStar=YStar,phi=phi),
               GRANDMEAN=anova$GRANDMEAN,
               MAINEFFECT=anova$MAINEFFECT,
               CHANGEBYEFFECT=anova$CHANGEBYEFFECT,
